@@ -302,7 +302,8 @@ void MainWindow::openArticleInPlayer(QString title, QString article)
      player->openArticle(title, article, openPlaylist);
      ui->playerButton->setDown(true);
      ui->mainWindowButton->setDown(false);
-     player->show();
+     if(!player->isVisible())
+        player->show();
 
      //message->hide();
 }
