@@ -63,12 +63,12 @@ void Player::openArticle(QString itemName, QString text, bool playlist)
 
 
     ui->articleBrowser->setText(text);
-    bool audioExists = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".wav").exists();
+    bool audioExists = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D)+".wav").exists();
 
     if (!playlist || !audioExists)
         audio->createWav(path);
     if (audioExists)
-        audio->setAudio(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".wav");
+        audio->setAudio(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D)+".wav");
 
     articleLoaded = true;
 
@@ -121,7 +121,7 @@ void Player::setPlaylistFocus()
     this->ui->playListWidget->setCurrentRow(1, QItemSelectionModel::Select);
 
     this->openArticleFromLink(ui->playListWidget->item(this->ui->playListWidget->currentRow()));
-    audio->createWav(this->ui->playListWidget->currentItem()->text());
+   // audio->createWav(this->ui->playListWidget->currentItem()->text());
 }
 
 void Player::on_playListWidget_itemClicked(QListWidgetItem *item)
